## 0.9.1 (2025-03-16)

### Fix

- Upgraded sigstore action, was also crashing CI

## 0.9.0 (2025-03-16)

### Feat

- Upgraded version of GH actions. Obsolete version was crashing CI

## 0.8.1 (2025-03-16)

### Fix

- Also updated readthedocs builder to 3.10 (doesn't affect code)

## 0.8.0 (2025-03-16)

### Feat

- Upgraded version requirements to python 3.10 and curvlinops >=2
- Implemented (sub-)diagonal and (block-)triangular sketched estimators (#1)

## 0.7.0 (2024-05-08)

### Feat

- Implemented (sub-)diagonal and (block-)triangular sketched estimators (#1)

## 0.6.1 (2024-03-25)

### Fix

- updated CI pipeline

## 0.6.0 (2024-03-24)

### Feat

- updated version in changelog and pyproject for consistent migration
- ready for beta release

## 0.5.0 (2024-03-24)

### Feat

- migrated repo from private
